@@ -1,8 +1,14 @@
 use std::boxed::Box as Box_;
 use std::collections::HashMap;
 
-use crate::{hashtable::attribute_names_and_values, Retrievable, Schema, SearchFlags, Value};
-use glib::{translate::*, Cast, IsA};
+use crate::{hashtable::attribute_names_and_values, Schema};
+#[cfg(any(feature = "v0_19", feature = "dox"))]
+#[cfg_attr(feature = "dox", doc(cfg(feature = "v0_19")))]
+use crate::{Retrievable, SearchFlags, Value};
+#[cfg(any(feature = "v0_19", feature = "dox"))]
+#[cfg_attr(feature = "dox", doc(cfg(feature = "v0_19")))]
+use glib::Cast;
+use glib::{translate::*, IsA};
 
 #[doc(alias = "secret_password_clearv_sync")]
 #[doc(alias = "secret_password_clear_sync")]
@@ -28,6 +34,8 @@ pub fn password_clear_sync(
     }
 }
 
+#[cfg(any(feature = "v0_19", feature = "dox"))]
+#[cfg_attr(feature = "dox", doc(cfg(feature = "v0_19")))]
 #[doc(alias = "secret_password_lookupv_binary_sync")]
 #[doc(alias = "secret_password_lookup_binary_sync")]
 #[doc(alias = "password_lookupv_binary_sync")]
@@ -100,6 +108,8 @@ pub fn password_lookup_sync(
     }
 }
 
+#[cfg(any(feature = "v0_19", feature = "dox"))]
+#[cfg_attr(feature = "dox", doc(cfg(feature = "v0_19")))]
 #[doc(alias = "secret_password_searchv_sync")]
 #[doc(alias = "secret_password_search_sync")]
 #[doc(alias = "password_searchv_sync")]
@@ -126,6 +136,8 @@ pub fn password_search_sync(
     }
 }
 
+#[cfg(any(feature = "v0_19", feature = "dox"))]
+#[cfg_attr(feature = "dox", doc(cfg(feature = "v0_19")))]
 #[doc(alias = "secret_password_storev_binary_sync")]
 #[doc(alias = "secret_password_store_binary_sync")]
 #[doc(alias = "password_storev_binary_sync")]
@@ -329,6 +341,8 @@ pub async fn password_lookup_future(
     .await
 }
 
+#[cfg(any(feature = "v0_19", feature = "dox"))]
+#[cfg_attr(feature = "dox", doc(cfg(feature = "v0_19")))]
 #[doc(alias = "secret_password_lookupv_binary")]
 #[doc(alias = "secret_password_lookup_binary")]
 #[doc(alias = "password_lookupv_binary")]
@@ -370,6 +384,8 @@ pub fn password_lookup_binary<P: FnOnce(Result<Option<Value>, glib::Error>) + 's
     }
 }
 
+#[cfg(any(feature = "v0_19", feature = "dox"))]
+#[cfg_attr(feature = "dox", doc(cfg(feature = "v0_19")))]
 #[doc(alias = "secret_password_lookupv_binary")]
 #[doc(alias = "secret_password_lookup_binary")]
 #[doc(alias = "password_lookupv_binary")]
@@ -559,6 +575,8 @@ pub async fn password_store_future(
     .await
 }
 
+#[cfg(any(feature = "v0_19", feature = "dox"))]
+#[cfg_attr(feature = "dox", doc(cfg(feature = "v0_19")))]
 #[doc(alias = "secret_password_storev_binary")]
 #[doc(alias = "secret_password_store_binary")]
 #[doc(alias = "password_storev_binary")]
@@ -604,6 +622,8 @@ pub fn password_store_binary<P: FnOnce(Result<(), glib::Error>) + 'static>(
     }
 }
 
+#[cfg(any(feature = "v0_19", feature = "dox"))]
+#[cfg_attr(feature = "dox", doc(cfg(feature = "v0_19")))]
 #[doc(alias = "secret_password_storev_binary")]
 #[doc(alias = "secret_password_store_binary")]
 #[doc(alias = "password_storev_binary")]
@@ -642,6 +662,8 @@ pub async fn password_store_binary_future(
     .await
 }
 
+#[cfg(any(feature = "v0_19", feature = "dox"))]
+#[cfg_attr(feature = "dox", doc(cfg(feature = "v0_19")))]
 #[doc(alias = "secret_password_searchv")]
 #[doc(alias = "secret_password_search")]
 #[doc(alias = "password_searchv")]
@@ -686,6 +708,8 @@ pub fn password_search<P: FnOnce(Result<Vec<Retrievable>, glib::Error>) + 'stati
     }
 }
 
+#[cfg(any(feature = "v0_19", feature = "dox"))]
+#[cfg_attr(feature = "dox", doc(cfg(feature = "v0_19")))]
 #[doc(alias = "secret_password_searchv")]
 #[doc(alias = "secret_password_search")]
 #[doc(alias = "password_searchv")]
